.. _k8s_ansible:

****************
Kubernetes Guide
****************

Welcome to the Ansible for Kubernetes Guide!

The purpose of this guide is to teach you everything you need to know about using Ansible with Kubernetes.

To get started, please select one of the following topics.

.. toctree::
   :maxdepth: 1

   kubernetes_scenarios/k8s_intro
   kubernetes_scenarios/k8s_inventory
   kubernetes_scenarios/k8s_scenarios
